@@ -213,18 +213,25 @@ while((h = fstReaderIterateHier(xc)))
 			s = *nam;
 			pnts = h->u.var.name;
 			pntd = s;
+
+			int esc_sm = 0;
 			while(*pnts)
 				{
+				if(*pnts == '\\') esc_sm = 1;
 				if(*pnts != ' ')
 					{
-					if(*pnts == '[') { lb_last = pntd; col_last = NULL; rb_last = NULL; }
-					else if(*pnts == ':' && lb_last != NULL && col_last == NULL && rb_last == NULL) { col_last = pntd; }
-					else if(*pnts == ']' && lb_last != NULL && rb_last == NULL) { rb_last = pntd; }
-					else if(lb_last != NULL && rb_last == NULL && (isdigit((int)(unsigned char)*pnts) || (*pnts == '-'))) { }
+					if(*pnts == '[' && !esc_sm) { lb_last = pntd; col_last = NULL; rb_last = NULL; }
+					else if(*pnts == ':' && lb_last != NULL && col_last == NULL && rb_last == NULL && !esc_sm) { col_last = pntd; }
+					else if(*pnts == ']' && lb_last != NULL && rb_last == NULL && !esc_sm) { rb_last = pntd; }
+					else if(lb_last != NULL && rb_last == NULL && (isdigit((int)(unsigned char)*pnts) || (*pnts == '-')) && !esc_sm) { }
 					else { lb_last = NULL; col_last = NULL; rb_last = NULL; }
 
 					*(pntd++) = *pnts;
 					}
+				else
+					{
+					esc_sm = 0;
+					}
 				pnts++;
 				}
 			*pntd = 0; *namlen = pntd - s;
@@ -968,7 +975,7 @@ for(i=0;i<GLOBALS->numfacs;i++)
 				}
 			s=&sym_block[i];
 		        symadd_name_exists_sym_exists(s,str,0);
-			if((allowed_to_autocoalesce)&&(prevsym)&&(revcmp)&&(!strchr(f_name[(i)&F_NAME_MODULUS], '\\')))	/* allow chaining for search functions.. */
+			if((allowed_to_autocoalesce)&&(prevsym)&&(revcmp)) /* allow chaining for search functions.. NOTE: removed &&(!strchr(f_name[(i)&F_NAME_MODULUS], '\\')) because of esc_sm fix */
 				{
 				prevsym->vec_root = prevsymroot;
 				prevsym->vec_chain = s;
