@@ -148,7 +148,7 @@ static struct fstHier *extractNextVar(void *xc, int *msb, int *lsb, char **nam,
 {
 struct fstHier *h;
 const char *pnts;
-char *pnt, *pntd, *lb_last = NULL, *col_last = NULL; /* *rb_last = NULL; */ /* scan-build : unused */
+char *pnt, *pntd, *lb_last = NULL, *col_last = NULL, *rb_last = NULL;
 int acc;
 char *s;
 unsigned char ttype;
@@ -215,20 +215,35 @@ while((h = fstReaderIterateHier(xc)))
 			s = *nam;
 			pnts = h->u.var.name;
 			pntd = s;
+
+			int esc_sm = 0;
 			while(*pnts)
 				{
+				if(*pnts == '\\') esc_sm = 1;
 				if(*pnts != ' ')
 					{
-					if(*pnts == '[') { lb_last = pntd; col_last = NULL; }
-					else if(*pnts == ':') { col_last = pntd; }
-					/* else if(*pnts == ']') { rb_last = pntd; } */ /* scan-build : unused */
+					if(*pnts == '[' && !esc_sm) { lb_last = pntd; col_last = NULL; rb_last = NULL; }
+					else if(*pnts == ':' && lb_last != NULL && col_last == NULL && rb_last == NULL && !esc_sm) { col_last = pntd; }
+					else if(*pnts == ']' && lb_last != NULL && rb_last == NULL && !esc_sm) { rb_last = pntd; }
+					else if(lb_last != NULL && rb_last == NULL && (isdigit((int)(unsigned char)*pnts) || (*pnts == '-')) && !esc_sm) { }
+					else { lb_last = NULL; col_last = NULL; rb_last = NULL; }
 
 					*(pntd++) = *pnts;
 					}
+				else
+					{
+					esc_sm = 0;
+					}
 				pnts++;
 				}
 			*pntd = 0; *namlen = pntd - s;
 
+			if(!rb_last)
+				{
+				col_last = NULL;
+				lb_last = NULL;
+				}
+
 			if(!lb_last)
 				{
 				*msb = *lsb = -1;
@@ -962,7 +977,7 @@ for(i=0;i<GLOBALS->numfacs;i++)
 				}
 			s=&sym_block[i];
 		        symadd_name_exists_sym_exists(s,str,0);
-			if((allowed_to_autocoalesce)&&(prevsym)&&(revcmp)&&(!strchr(f_name[(i)&F_NAME_MODULUS], '\\')))	/* allow chaining for search functions.. */
+			if((allowed_to_autocoalesce)&&(prevsym)&&(revcmp)) /* allow chaining for search functions.. NOTE: removed &&(!strchr(f_name[(i)&F_NAME_MODULUS], '\\')) because of esc_sm fix */
 				{
 				prevsym->vec_root = prevsymroot;
 				prevsym->vec_chain = s;
@@ -1522,7 +1537,7 @@ else	/* string */
 		{
 		if((!strcmp(l2e->histent_curr->v.h_vector, (const char *)value)) && (!GLOBALS->vcd_preserve_glitches))
 			{
-			free(s);
+			free_2(s);
 			return;
 			}
 		}
