@@ -363,6 +363,7 @@ JRB enum_nptrs_jrb;
  * ghw.c
  */
 struct Node **nxp_ghw_c_1; /* from ghw.c 95 */
+uint32_t nbr_sigs_ghw_c_1;
 int sym_which_ghw_c_1; /* from ghw.c 98 */
 struct ghw_tree_node *gwt_ghw_c_1; /* from ghw.c 99 */
 struct ghw_tree_node *gwt_corr_ghw_c_1; /* from ghw.c 100 */
@@ -784,7 +785,7 @@ char *editor_name; /* from rc.c */
 /*
  * regex.c
  */
-struct re_pattern_buffer *preg_regex_c_1; /* from regex.c 339 */
+regex_t *preg_regex_c_1; /* from regex.c 339 */
 int *regex_ok_regex_c_1; /* from regex.c 340 */
 
 
