@@ -1738,7 +1738,7 @@ if((wname)||(vcd_save_handle_cached)||(is_smartsave))
 	        str=wave_alloca(strlen(wname)+dlen+1);
 	        strcpy(str,WAVE_DECOMPRESSOR);
 	        strcpy(str+dlen,wname);
-	        wave=popen(str,"r");
+	        wave=popen_san(str,"r");
 	        wave_is_compressed=~0;
 	        }
 	        else
@@ -1786,7 +1786,7 @@ if((wname)||(vcd_save_handle_cached)||(is_smartsave))
 			if(wave_is_compressed)
 			        {
 				pclose(wave);
-			        wave=popen(str,"r");
+			        wave=popen_san(str,"r");
 			        }
 			        else
 			        {
@@ -3021,12 +3021,12 @@ if(GLOBALS->stems_type != WAVE_ANNO_NONE)
 	if(shmid >=0)
 		{
 		struct shmid_ds ds;
-
-		GLOBALS->anno_ctx = shmat(shmid, NULL, 0);
-		if(GLOBALS->anno_ctx)
+		struct gtkwave_annotate_ipc_t *anno_ctx = shmat(shmid, NULL, 0);
+		if(anno_ctx != (void *) -1)
 			{
 			pid_t pid;
 
+			GLOBALS->anno_ctx = anno_ctx;
 			memset(GLOBALS->anno_ctx, 0, sizeof(struct gtkwave_annotate_ipc_t));
 
 			memcpy(GLOBALS->anno_ctx->matchword, WAVE_MATCHWORD, 4);
