@@ -20,6 +20,18 @@
 #ifndef GDK_KEY_equal
 #define GDK_KEY_equal GDK_equal
 #endif
+#ifndef GDK_KEY_Up
+#define GDK_KEY_Up GDK_Up
+#endif
+#ifndef GDK_KEY_KP_Up
+#define GDK_KEY_KP_Up GDK_KP_Up
+#endif
+#ifndef GDK_KEY_Down
+#define GDK_KEY_Down GDK_Down
+#endif
+#ifndef GDK_KEY_KP_Down
+#define GDK_KEY_KP_Down GDK_KP_Down
+#endif
 
 #undef FOCUS_DEBUG_MSGS
 
@@ -471,6 +483,7 @@ int target;
 int which;
 gint rc = FALSE;
 int yscroll;
+int ud_kill = 0;
 
 #ifdef FOCUS_DEBUG_MSGS
 printf("focus: %d %08x %08x %08x\n", GTK_WIDGET_HAS_FOCUS(GLOBALS->signalarea_event_box),
@@ -549,7 +562,128 @@ if(GTK_WIDGET_HAS_FOCUS(GLOBALS->signalarea_event_box))
 			num_traces_displayable=(GLOBALS->signalarea->allocation.height)/(GLOBALS->fontheight);
 			num_traces_displayable--;   /* for the time trace that is always there */
 
-			if(num_traces_displayable<GLOBALS->traces.visible)
+                        if(event->state & GDK_SHIFT_MASK)
+                                {
+                                Trptr t = NULL, t2 = NULL;
+				Trptr tc = NULL, th = NULL;
+				int num_high = 0;
+
+                                if((event->keyval == GDK_KEY_Up) || (event->keyval == GDK_KEY_KP_Up))
+                                        {
+                                        ud_kill = 1;
+                                        for(t=GLOBALS->traces.first;t;t=t->t_next)
+                                                {
+                                                if(t->flags&TR_HIGHLIGHT)
+                                                        {
+                                                        if(!th) th = t;
+                                                        num_high++;
+                                                        }
+
+                                                if(t->is_cursor)
+                                                        {
+                                                        tc = t;
+                                                        }
+                                                }
+
+                                        if(num_high <= 1)
+                                                {
+                                                t = th ? GivePrevTrace(th) : GLOBALS->topmost_trace;
+                                                }
+                                                else
+                                                {
+                                                t = tc ? GivePrevTrace(tc) : GLOBALS->topmost_trace;
+                                                }
+
+                                        MarkTraceCursor(t);
+                                        }
+                                else
+                                if((event->keyval == GDK_KEY_Down) || (event->keyval == GDK_KEY_KP_Down))
+                                        {
+                                        ud_kill = 1;
+                                        for(t=GLOBALS->traces.first;t;t=t->t_next)
+                                                {
+                                                if(t->flags&TR_HIGHLIGHT)
+                                                        {
+                                                        th = t;
+                                                        num_high++;
+                                                        }
+                                                if(t->is_cursor)
+                                                        {
+                                                        tc = t;
+                                                        }
+                                                }
+
+                                        if(num_high <= 1)
+                                                {
+                                                t = th ? GiveNextTrace(th) : GLOBALS->topmost_trace;
+                                                }
+                                                else
+                                                {
+                                                if(tc)
+                                                      	{
+                                                        t = GiveNextTrace(tc);
+                                                        }
+                                                else
+                                                    	{
+                                                        t = th ? GiveNextTrace(th) : GLOBALS->topmost_trace;
+                                                        }
+                                                }
+
+                                        MarkTraceCursor(t);
+                                        }
+
+                                if(t)
+                                     	{
+                                        int top_target = 0;
+                                        target = 0;
+                                        which=num_traces_displayable-1;
+
+                                        ClearTraces();
+                                        t->flags |= TR_HIGHLIGHT;
+                                        t2 = t;
+
+                                        for(t=GLOBALS->traces.first;t;t=GiveNextTrace(t))
+                                                {
+                                                if(t == GLOBALS->topmost_trace) break;
+                                                top_target++;
+                                                }
+
+                                        for(t=GLOBALS->traces.first;t;t=GiveNextTrace(t))
+                                                {
+                                                if(t2 == t) break;
+                                                target++;
+                                                }
+
+                                        if((target >= top_target) && (target <= top_target+which))
+                                                {
+                                                /* nothing */
+                                                }
+                                                else
+                                                {
+                                                if((event->keyval == GDK_KEY_Up) || (event->keyval == GDK_KEY_KP_Up))
+                                                        {
+                                                        if(target<0) target=0;
+                                                        }
+                                                else
+                                                if((event->keyval == GDK_KEY_Down) || (event->keyval == GDK_KEY_KP_Down))
+                                                        {
+                                                        target = target - which;
+                                                        if(target+which>=(GLOBALS->traces.visible-1)) target=GLOBALS->traces.visible-which-1;
+                                                        }
+
+						wadj->value = target;
+                                                }
+
+                                        if(GLOBALS->cachedwhich_signalwindow_c_1==which) GLOBALS->cachedwhich_signalwindow_c_1=which-1; /* force update */
+
+                                        gtk_signal_emit_by_name (GTK_OBJECT (wadj), "changed"); /* force bar update */
+                                        gtk_signal_emit_by_name (GTK_OBJECT (wadj), "value_changed"); /* force text update */
+					signalarea_configure_event(GLOBALS->signalarea, NULL);
+					wavearea_configure_event(GLOBALS->wavearea, NULL);
+                                        }
+                                }
+
+			if((num_traces_displayable<GLOBALS->traces.visible) && (!ud_kill))
 				{
 				switch(event->keyval)
 					{
@@ -568,6 +702,8 @@ if(GTK_WIDGET_HAS_FOCUS(GLOBALS->signalarea_event_box))
 
                         			gtk_signal_emit_by_name (GTK_OBJECT (wadj), "changed"); /* force bar update */
                         			gtk_signal_emit_by_name (GTK_OBJECT (wadj), "value_changed"); /* force text update */
+						signalarea_configure_event(GLOBALS->signalarea, NULL);
+						wavearea_configure_event(GLOBALS->wavearea, NULL);
 						break;
 
 					case GDK_Up:
@@ -659,8 +795,21 @@ if(GLOBALS->dnd_sigview)
 		  if(event->state & GDK_CONTROL_MASK)
 #endif
 		    {
-		      treeview_select_all_callback();
-		      rc = TRUE;
+#ifdef WAVE_USE_GTK2
+                      if(!gtk_widget_has_focus(GLOBALS->filter_entry))
+                                {
+                                treeview_select_all_callback();
+                                rc = TRUE;
+                                }
+                      else
+                                {
+                                gtk_editable_select_region (GTK_EDITABLE (GLOBALS->filter_entry),0, gtk_entry_get_text_length(GTK_ENTRY(GLOBALS->filter_entry)));
+                                rc = TRUE;
+                                }
+#else
+                                treeview_select_all_callback();
+                                rc = TRUE;
+#endif
 		    }
 		  break;
 
@@ -671,8 +820,21 @@ if(GLOBALS->dnd_sigview)
 		  if(event->state & GDK_CONTROL_MASK)
 #endif
 		    {
-		      treeview_unselect_all_callback();
-		      rc = TRUE;
+#ifdef WAVE_USE_GTK2
+                      if(!gtk_widget_has_focus(GLOBALS->filter_entry))
+                                {
+                                treeview_unselect_all_callback();
+                                rc = TRUE;
+                                }
+                        else
+                                {
+                                gtk_editable_select_region (GTK_EDITABLE (GLOBALS->filter_entry),0, 0);
+                                rc = TRUE;
+                                }
+#else
+                                treeview_unselect_all_callback();
+                                rc = TRUE;
+#endif
 		    }
 		default:
 		  break;
@@ -1228,14 +1390,14 @@ if((GLOBALS->traces.visible)&&(GLOBALS->signalpixmap))
 		    }
 		  else
 		    {
-		      t->flags ^= TR_HIGHLIGHT;
+		      t->flags ^= TR_HIGHLIGHT; MarkTraceCursor(t);
 		    }
 		  }
 		}
 	else
 	if((event->state&GDK_SHIFT_MASK)&&(GLOBALS->starting_unshifted_trace))
 		{
-		int src = -1, dst = -1;
+		int src = -1, dst = -1, dsto = -1;
 		int cnt = 0;
 
 		t2=GLOBALS->traces.first;
@@ -1265,6 +1427,7 @@ if((GLOBALS->traces.visible)&&(GLOBALS->signalpixmap))
 				  cnt++;
 				}
 
+			dsto = dst;
 			if(src > dst) { int cpy; cpy = src; src = dst; dst = cpy; }
 			cnt = 0;
 			t2=GLOBALS->traces.first;
@@ -1275,6 +1438,8 @@ if((GLOBALS->traces.visible)&&(GLOBALS->signalpixmap))
 					  t2->flags |= TR_HIGHLIGHT;
 					}
 
+				if(cnt == dsto) { MarkTraceCursor(t2); }
+
 				cnt++;
 				t2=t2->t_next;
 				}
@@ -1298,7 +1463,7 @@ else if( (!GLOBALS->use_standard_trace_select) || (GLOBALS->standard_trace_dnd_d
 			t2 = t2->t_next;
 			}
 
-		if(t) { t->flags |= TR_HIGHLIGHT; } /* scan-build */
+		if(t) { t->flags |= TR_HIGHLIGHT; MarkTraceCursor(t); } /* scan-build */
 		}
 
 	GLOBALS->standard_trace_dnd_degate = 0;
