@@ -340,6 +340,7 @@ errno = 0;
 if(feof(GLOBALS->vcd_handle_vcd_c_1)) return(-1);
 
 GLOBALS->vcdbyteno_vcd_c_1+=(GLOBALS->vend_vcd_c_1-GLOBALS->vcdbuf_vcd_c_1);
+memset(GLOBALS->vcdbuf_vcd_recoder_c_3, 0, VCD_BSIZ);
 rd=fread(GLOBALS->vcdbuf_vcd_c_1, sizeof(char), VCD_BSIZ, GLOBALS->vcd_handle_vcd_c_1);
 GLOBALS->vend_vcd_c_1=(GLOBALS->vst_vcd_c_1=GLOBALS->vcdbuf_vcd_c_1)+rd;
 
@@ -357,13 +358,13 @@ return((int)(*GLOBALS->vst_vcd_c_1));
 static inline signed char getch(void) {
   signed char ch = ((GLOBALS->vst_vcd_c_1!=GLOBALS->vend_vcd_c_1)?((int)(*GLOBALS->vst_vcd_c_1)):(getch_fetch()));
   GLOBALS->vst_vcd_c_1++;
-  return(ch);
+  return(ch ? ch : -1);
 }
 
 static inline signed char getch_peek(void) {
   signed char ch = ((GLOBALS->vst_vcd_c_1!=GLOBALS->vend_vcd_c_1)?((int)(*GLOBALS->vst_vcd_c_1)):(getch_fetch()));
   /* no increment */
-  return(ch);
+  return(ch ? ch : -1);
 }
 
 
@@ -549,7 +550,16 @@ for(GLOBALS->yytext_vcd_c_1[len++]=ch;;GLOBALS->yytext_vcd_c_1[len++]=ch)
 	{
 	if(len==GLOBALS->T_MAX_STR_vcd_c_1)
 		{
-		GLOBALS->yytext_vcd_c_1=(char *)realloc_2(GLOBALS->yytext_vcd_c_1, (GLOBALS->T_MAX_STR_vcd_c_1=GLOBALS->T_MAX_STR_vcd_c_1*2)+1);
+		if(!GLOBALS->varsplit_vcd_c_1)
+			{
+			GLOBALS->yytext_vcd_c_1=(char *)realloc_2(GLOBALS->yytext_vcd_c_1, (GLOBALS->T_MAX_STR_vcd_c_1=GLOBALS->T_MAX_STR_vcd_c_1*2)+1);
+			}
+                else /* TALOS-2023-1806 */
+                        {
+                        int vsplit_len = GLOBALS->varsplit_vcd_c_1 - GLOBALS->yytext_vcd_c_1; /* save old len */
+			GLOBALS->yytext_vcd_c_1=(char *)realloc_2(GLOBALS->yytext_vcd_c_1, (GLOBALS->T_MAX_STR_vcd_c_1=GLOBALS->T_MAX_STR_vcd_c_1*2)+1);
+                        GLOBALS->varsplit_vcd_c_1 = GLOBALS->yytext_vcd_c_1+vsplit_len; /* reconstruct old len in new buffer */
+                        }
 		}
 
         ch=getch();
@@ -962,7 +972,7 @@ switch(GLOBALS->yytext_vcd_c_1[0])
 				}
 				else
 				{
-				if(GLOBALS->yylen_cache_vcd_c_1<v->size)
+				if(GLOBALS->yylen_cache_vcd_c_1<=v->size) /* TALOS-2023-1804 */
 					{
 					free_2(vector);
 					vector=malloc_2(v->size+1);
@@ -1245,7 +1255,7 @@ for(;;)
 			sync_end(NULL);
 			break;
 		case T_VAR:
-			if((GLOBALS->header_over_vcd_c_1)&&(0))
+			if(GLOBALS->header_over_vcd_c_1) /* reinstated because of TALOS-2023-1805 */
 			{
 			fprintf(stderr,"$VAR encountered after $ENDDEFINITIONS near byte %d.  VCD is malformed, exiting.\n",
 				(int)(GLOBALS->vcdbyteno_vcd_c_1+(GLOBALS->vst_vcd_c_1-GLOBALS->vcdbuf_vcd_c_1)));
@@ -2626,7 +2636,7 @@ if(suffix_check(fname, ".gz") || suffix_check(fname, ".zip"))
 	str=wave_alloca(strlen(fname)+dlen+1);
 	strcpy(str,WAVE_DECOMPRESSOR);
 	strcpy(str+dlen,fname);
-	GLOBALS->vcd_handle_vcd_c_1=popen(str,"r");
+	GLOBALS->vcd_handle_vcd_c_1=popen_san(str,"r");
 	GLOBALS->vcd_is_compressed_vcd_c_1=~0;
 	}
 	else
