@@ -848,6 +848,7 @@ errno = 0;
 if(feof(GLOBALS->vcd_handle_vcd_recoder_c_2)) return(-1);
 
 GLOBALS->vcdbyteno_vcd_recoder_c_3+=(GLOBALS->vend_vcd_recoder_c_3-GLOBALS->vcdbuf_vcd_recoder_c_3);
+memset(GLOBALS->vcdbuf_vcd_recoder_c_3, 0, VCD_BSIZ);
 rd=fread(GLOBALS->vcdbuf_vcd_recoder_c_3, sizeof(char), VCD_BSIZ, GLOBALS->vcd_handle_vcd_recoder_c_2);
 GLOBALS->vend_vcd_recoder_c_3=(GLOBALS->vst_vcd_recoder_c_3=GLOBALS->vcdbuf_vcd_recoder_c_3)+rd;
 
@@ -864,13 +865,13 @@ return((int)(*GLOBALS->vst_vcd_recoder_c_3));
 static inline signed char getch(void) {
   signed char ch = (GLOBALS->vst_vcd_recoder_c_3!=GLOBALS->vend_vcd_recoder_c_3)?((int)(*GLOBALS->vst_vcd_recoder_c_3)):(getch_fetch());
   GLOBALS->vst_vcd_recoder_c_3++;
-  return(ch);
+  return(ch ? ch : -1);
 }
 
 static inline signed char getch_peek(void) {
   signed char ch = (GLOBALS->vst_vcd_recoder_c_3!=GLOBALS->vend_vcd_recoder_c_3)?((int)(*GLOBALS->vst_vcd_recoder_c_3)):(getch_fetch());
   /* no increment */
-  return(ch);
+  return(ch ? ch : -1);
 }
 
 static int getch_patched(void)
